@@ -25,7 +25,7 @@ Usage::
     list_compatible_images_paginator: ListCompatibleImagesPaginator = client.get_paginator("list_compatible_images")
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
 """
-from mypy_boto3_snowball.client import SnowballClient, SnowballClient as Client
+from mypy_boto3_snowball.client import SnowballClient as Client, SnowballClient
 from mypy_boto3_snowball.paginator import (
     DescribeAddressesPaginator,
     ListClusterJobsPaginator,
