@@ -21,9 +21,7 @@ Usage::
     list_jobs_paginator: ListJobsPaginator = client.get_paginator("list_jobs")
 """
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
-from __future__ import annotations
-
-from typing import Generator
+from typing import Generator, TYPE_CHECKING
 from botocore.paginate import Paginator as Boto3Paginator
 from mypy_boto3_snowball.type_defs import (
     DescribeAddressesResultTypeDef,
@@ -46,64 +44,64 @@ __all__ = (
 
 class DescribeAddressesPaginator(Boto3Paginator):
     """
-    [Paginator.DescribeAddresses documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses)
+    [Paginator.DescribeAddresses documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[DescribeAddressesResultTypeDef, None, None]:
         """
-        [DescribeAddresses.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses.paginate)
+        [DescribeAddresses.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.DescribeAddresses.paginate)
         """
 
 
 class ListClusterJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListClusterJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs)
+    [Paginator.ListClusterJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs)
     """
 
     def paginate(
         self, ClusterId: str, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListClusterJobsResultTypeDef, None, None]:
         """
-        [ListClusterJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs.paginate)
+        [ListClusterJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListClusterJobs.paginate)
         """
 
 
 class ListClustersPaginator(Boto3Paginator):
     """
-    [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListClusters)
+    [Paginator.ListClusters documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListClusters)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListClustersResultTypeDef, None, None]:
         """
-        [ListClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListClusters.paginate)
+        [ListClusters.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListClusters.paginate)
         """
 
 
 class ListCompatibleImagesPaginator(Boto3Paginator):
     """
-    [Paginator.ListCompatibleImages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages)
+    [Paginator.ListCompatibleImages documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListCompatibleImagesResultTypeDef, None, None]:
         """
-        [ListCompatibleImages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages.paginate)
+        [ListCompatibleImages.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListCompatibleImages.paginate)
         """
 
 
 class ListJobsPaginator(Boto3Paginator):
     """
-    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListJobs)
+    [Paginator.ListJobs documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListJobs)
     """
 
     def paginate(
         self, PaginationConfig: PaginatorConfigTypeDef = None
     ) -> Generator[ListJobsResultTypeDef, None, None]:
         """
-        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.10.48/reference/services/snowball.html#Snowball.Paginator.ListJobs.paginate)
+        [ListJobs.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.12.6/reference/services/snowball.html#Snowball.Paginator.ListJobs.paginate)
         """
